module SgtnCldr
      module Core
            autoload :Cache,        "sgtn-cldr/core/cache"
      end

      autoload :Translation,        "sgtn-cldr/api/translation"
      autoload :Source,             "sgtn-cldr/api/source"
      autoload :Config,             "sgtn-cldr/core/config"
      autoload :Logging,            "sgtn-cldr/core/logging"
      autoload :Exceptions,         "sgtn-cldr/core/exceptions"
      autoload :ValidateUtil,       "sgtn-cldr/util/validate-util"

      class << self
            def configure(options = {}, &block)
            SgtnCldr::Config.configure(options, &block)
            end

            include Logging
            def load(*args)
                  # load configuration file
                  begin
                    SgtnCldr::Config.load(args[0], args[1])
                    SgtnCldr::ValidateUtil.validate_config()
                  rescue => exception
                    file = File.open('./error.log', 'a')
                    file.sync = true
                    log = Logger.new(file)
                    log.error exception.message
                  end

                  # create log file
                  file = './sgtncldr_d.log'
                  if args[2] != nil
                        file = args[2]
                  end
                  file = File.open(file, 'a')
                  file.sync = true
                  SgtnCldr.logger = Logger.new(file)

                  # Set log level for sandbox mode
                  env = SgtnCldr::Config.default_environment
                  mode = SgtnCldr::Config.configurations[env]["mode"]
                  SgtnCldr.logger.info "Current mode is: " + mode
                  if mode == 'sandbox'
                        SgtnCldr.logger.level = Logger::DEBUG
                  else 
                        SgtnCldr.logger.level = Logger::INFO
                  end

                  # initialize cache
                  disable_cache = SgtnCldr::Config.configurations[env]["disable_cache"]
                  if disable_cache != nil
                        SgtnCldr::Core::Cache.initialize(disable_cache)
                  else
                        SgtnCldr::Core::Cache.initialize()
                  end
            end

            def logger
                  SgtnCldr::Config.logger
            end

            def logger=(log)
                  SgtnCldr::Config.logger = log
            end           
      end
  
end

require 'twitter_cldr'
require 'sgtn-cldr/cldr/core_ext'